FKappaEnv class

A container for environment-specific configuration.

Constructors

FKappaEnv({required FKappaFlavor flavor, required String baseUrl, String? apiKey, String? sentryDsn, Map<String, dynamic> extra = const {}})
const

Properties

apiKey String?
final
baseUrl String
final
extra Map<String, dynamic>
final
flavor FKappaFlavor
final
hashCode int
The hash code for this object.
no setterinherited
isDev bool
no setter
isProd bool
no setter
isStaging bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentryDsn String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited