core/architecture/kappa_middleware library

Classes

AuthMiddleware
Protects routes that require a logged-in user.
FKappaMiddleware
The contract for all middlewares in FKappa. A middleware can intercept a navigation and decide to redirect or allow it.
GuestMiddleware
Protects routes that should only be accessible to guests (e.g., Login, Register).