AuthMiddleware class
Protects routes that require a logged-in user.
- Inheritance
-
- Object
- FKappaMiddleware
- AuthMiddleware
Constructors
- AuthMiddleware({required bool isAuthenticated(), String loginPath = '/login'})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAuthenticated → bool Function()
-
final
- loginPath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handle(
BuildContext context, GoRouterState state) → FutureOr< String?> -
Logic to decide if the navigation should be redirected.
Returns a path to redirect to, or null to allow navigation.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited