FKappaMiddleware class abstract

The contract for all middlewares in FKappa. A middleware can intercept a navigation and decide to redirect or allow it.

Implementers

Constructors

FKappaMiddleware()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle(BuildContext context, GoRouterState state) FutureOr<String?>
Logic to decide if the navigation should be redirected. Returns a path to redirect to, or null to allow navigation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited