handle abstract method

FutureOr<String?> handle(
  1. BuildContext context,
  2. GoRouterState state
)

Logic to decide if the navigation should be redirected. Returns a path to redirect to, or null to allow navigation.

Implementation

FutureOr<String?> handle(BuildContext context, GoRouterState state);