CacheFailure class

A standard Cache Failure (e.g., local storage read/write error).

Inheritance

Constructors

CacheFailure(String message, {StackTrace? stackTrace, dynamic exception})
const

Properties

exception → dynamic
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited