Failure class abstract

Base class for all failures in the application. Use this class to standardize error handling in the Domain Layer.

Implementers

Constructors

Failure(String message, {StackTrace? stackTrace, dynamic exception})
const

Properties

exception → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited