HydratedStorage constructor
Implementation of Storage which uses package:hive_ce to persist and retrieve state changes from the local device.
Implementation
@visibleForTesting
HydratedStorage(this._box);
Implementation of Storage which uses package:hive_ce to persist and retrieve state changes from the local device.
@visibleForTesting
HydratedStorage(this._box);