isStop property
bool
get
isStop
Whether this block represents a hard stop without a follow-up callback.
Implementation
bool get isStop => this is Block && then == null;
Whether this block represents a hard stop without a follow-up callback.
bool get isStop => this is Block && then == null;