ResponsiveUtils class

Util functions for the Responsive Framework.

Constructors

ResponsiveUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

breakpointComparator(Breakpoint a, Breakpoint b) int
Comparator function to order Breakpoints from small to large by start sections.
debugLogBreakpoints(List<Breakpoint>? breakpoints) String
Print a visual view of breakpoints for debugging purposes.