breakpointComparator static method
Comparator function to order Breakpoints from small to large by start sections.
Implementation
static int breakpointComparator(Breakpoint a, Breakpoint b) {
return a.start.compareTo(b.start);
}
Comparator function to order Breakpoints from small to large by start sections.
static int breakpointComparator(Breakpoint a, Breakpoint b) {
return a.start.compareTo(b.start);
}