router property
The GoRouter instance that owns this configuration.
This is used to provide access to the router during redirects.
Implementation
final GoRouter? router;
The GoRouter instance that owns this configuration.
This is used to provide access to the router during redirects.
final GoRouter? router;