buildPage abstract method
Attempts to build the Page representing this shell route.
Returns null if this shell route does not build a Page, but instead uses a Widget to represent itself (see buildWidget).
Implementation
Page<dynamic>? buildPage(
BuildContext context,
GoRouterState state,
ShellRouteContext shellRouteContext,
);