decoder property
A function that converts a string from the URI to a parameter value.
See QueryParameterDecoder for details.
Implementation
final QueryParameterDecoder<T>? decoder;
A function that converts a string from the URI to a parameter value.
See QueryParameterDecoder for details.
final QueryParameterDecoder<T>? decoder;