encoder property
A function that converts a parameter value to a string for use in the URI.
See QueryParameterEncoder for details.
Implementation
final QueryParameterEncoder<T>? encoder;
A function that converts a parameter value to a string for use in the URI.
See QueryParameterEncoder for details.
final QueryParameterEncoder<T>? encoder;