TypedStatefulShellRoute<T extends StatefulShellRouteData> class

A superclass for each typed shell route descendant

Inheritance
Annotations
  • @Target.new(<TargetKind>{TargetKind.library, TargetKind.classType})

Constructors

TypedStatefulShellRoute({bool notifyRootObserver = true, List<TypedStatefulShellBranch<StatefulShellBranchData>> branches = const <TypedStatefulShellBranch<StatefulShellBranchData>>[]})
Default const constructor
const

Properties

branches List<TypedStatefulShellBranch<StatefulShellBranchData>>
Child route definitions.
final
hashCode int
The hash code for this object.
no setterinherited
notifyRootObserver bool
Whether navigation changes within this shell route will notify the GoRouter's observers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited