notifyRootObserver property
Whether navigation changes within this shell route will notify the GoRouter's observers.
Implementation
final bool notifyRootObserver;
Whether navigation changes within this shell route will notify the GoRouter's observers.
final bool notifyRootObserver;