isLazy property
bool
get
isLazy
Whether this module should be loaded only when its routes are accessed.
Implementation
bool get isLazy => false;
Whether this module should be loaded only when its routes are accessed.
bool get isLazy => false;