FKappaLoading class

Controller to manage global loading state. Use FKappaLoading.show() and FKappaLoading.hide() to control the overlay.

Constructors

FKappaLoading()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

state ValueNotifier<bool>
no setter

Static Methods

hide() → void
Hide the global loading overlay.
show() → void
Show the global loading overlay.