FKappaAnimationConstants class
Standard durations and curves for FKappa animations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- decelerateEasing → const Curve
- emphasizeEasing → const Curve
- fast → const Duration
- medium → const Duration
- slow → const Duration
- standardEasing → const Curve