FKappaDesignTokens class

Design Tokens for consistent spacing and styling.

Constructors

FKappaDesignTokens()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

elevationHigh → const double
elevationLow → const double
elevationNone → const double
radiusLarge → const double
radiusMedium → const double
radiusSmall → const double