FKappaThemeExtension class

Extends the Material Theme with FKappa specific tokens.

Inheritance

Constructors

FKappaThemeExtension({required Color brandColor, double defaultRadius = 8.0})
const

Properties

brandColor Color
final
defaultRadius double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Object
The extension's type.
no setterinherited

Methods

copyWith({Color? brandColor, double? defaultRadius}) FKappaThemeExtension
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<FKappaThemeExtension>? other, double t) FKappaThemeExtension
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) FKappaThemeExtension