core/architecture/kappa_middleware library
Classes
- AuthMiddleware
- Protects routes that require a logged-in user.
- GuestMiddleware
- Protects routes that should only be accessible to guests (e.g., Login, Register).
- KappaMiddleware
- The contract for all middlewares in Kappa. A middleware can intercept a navigation and decide to redirect or allow it.