handle abstract method
Logic to decide if the navigation should be redirected. Returns a path to redirect to, or null to allow navigation.
Implementation
FutureOr<String?> handle(BuildContext context, GoRouterState state);
Logic to decide if the navigation should be redirected. Returns a path to redirect to, or null to allow navigation.
FutureOr<String?> handle(BuildContext context, GoRouterState state);