FKappaDio class
A standardized Networking Client for FKappa with Offline-First support.
Constructors
Properties
- cacheOptions → CacheOptions?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get<
T> (String path, {Map< String, dynamic> ? queryParameters, Options? options}) → Future<Either< Failure, Response< >T> > - Perform a GET request.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
post<
T> (String path, {dynamic data, Map< String, dynamic> ? queryParameters, Options? options}) → Future<Either< Failure, Response< >T> > - Perform a POST request.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited