Block.then constructor
const
Block.then(
- OnEnterThenCallback then
Creates a Block that runs then after the navigation is blocked.
Keeps the redirection history to detect loops during chained redirects.
Implementation
const Block.then(OnEnterThenCallback then) : super(then: then);