TypedRelativeGoRoute<T extends RelativeGoRouteData> class
A superclass for each typed relative go route descendant
- Inheritance
-
- Object
- TypedRoute<
T> - TypedRelativeGoRoute
- Annotations
-
- @Target.new(<TargetKind>{TargetKind.library, TargetKind.classType})
Constructors
-
TypedRelativeGoRoute({required String path, List<
TypedRoute< routes = const <TypedRoute<RouteData>>[], bool caseSensitive = true})RouteData> > -
Default const constructor
const
Properties
- caseSensitive → bool
-
Determines whether the route matching is case sensitive.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
The relative path that corresponds to this route.
final
-
routes
→ List<
TypedRoute< RouteData> > -
Child route definitions.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited